You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@tomcat.apache.org by re...@apache.org on 2015/07/01 10:33:20 UTC

svn commit: r1688586 - /tomcat/trunk/java/org/apache/catalina/storeconfig/CredentialHandlerSF.java

Author: remm
Date: Wed Jul  1 08:33:20 2015
New Revision: 1688586

URL: http://svn.apache.org/r1688586
Log:
Fix old cut & paste names.

Modified:
    tomcat/trunk/java/org/apache/catalina/storeconfig/CredentialHandlerSF.java

Modified: tomcat/trunk/java/org/apache/catalina/storeconfig/CredentialHandlerSF.java
URL: http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/catalina/storeconfig/CredentialHandlerSF.java?rev=1688586&r1=1688585&r2=1688586&view=diff
==============================================================================
--- tomcat/trunk/java/org/apache/catalina/storeconfig/CredentialHandlerSF.java (original)
+++ tomcat/trunk/java/org/apache/catalina/storeconfig/CredentialHandlerSF.java Wed Jul  1 08:33:20 2015
@@ -59,23 +59,23 @@ public class CredentialHandlerSF extends
     }
 
     /**
-     * Store the specified Realm properties and child (Realm)
+     * Store the specified CredentialHandler properties and child (CredentialHandler)
      *
      * @param aWriter
      *            PrintWriter to which we are storing
      * @param indent
      *            Number of spaces to indent this element
      * @param aRealm
      *            Realm whose properties are being stored
      *
      * @exception Exception
      *                if an exception occurs while storing
      */
     @Override
-    public void storeChildren(PrintWriter aWriter, int indent, Object aRealm,
+    public void storeChildren(PrintWriter aWriter, int indent, Object aCredentialHandler,
             StoreDescription parentDesc) throws Exception {
-        if (aRealm instanceof NestedCredentialHandler) {
-            NestedCredentialHandler nestedCredentialHandler = (NestedCredentialHandler) aRealm;
+        if (aCredentialHandler instanceof NestedCredentialHandler) {
+            NestedCredentialHandler nestedCredentialHandler = (NestedCredentialHandler) aCredentialHandler;
 
             // Store nested <CredentialHandler> element
             CredentialHandler[] credentialHandlers = nestedCredentialHandler.getCredentialHandlers();



---------------------------------------------------------------------
@@ -59,23 +59,23 @@ public class CredentialHandlerSF extends
      * @param indent
      *            Number of spaces to indent this element
-     * @param aRealm
-     *            Realm whose properties are being stored
+     * @param aCredentialHandler
+     *            CredentialHandler whose properties are being stored
      *
      * @exception Exception
To unsubscribe, e-mail: dev-unsubscribe@tomcat.apache.org
For additional commands, e-mail: dev-help@tomcat.apache.org